#Night Light Pico W Code
#import the necessary libraries for our build
import time, board, mount_sd, busio
import os, time, ssl, wifi, socketpool, adafruit_requests
import rtc, circuitpython_schedule as schedule

#set up audio with imports and where your speaker is connected to
from audiocore import WaveFile
from audiomp3 import MP3Decoder
from audiopwmio import PWMAudioOut as AudioOut
audio = AudioOut(board.GP15)

#from here down is optional
#set alarm time
alarm = ["15:44"]
path2 = "/sd/alarm/"

#set up alarm function:
def play_alarm(filename):
    with open(path2 + filename, "rb") as wave_file:
        wave = WaveFile(wave_file)
        audio.play(wave)
        while audio.playing:
            pass

#set up clock
clock = rtc.RTC()

# log into wifi nextwork using the data in settings.toml
wifi.radio.connect(os.getenv("WIFI_SSID"), os.getenv("WIFI_PASSWORD"))
print("Connected to WiFi")

# sockets set up an endpoint for communication as a resuable 'pool'
pool = socketpool.SocketPool(wifi.radio)
# create an object so that a request for web data can be made
requests = adafruit_requests.Session(pool, ssl.create_default_context())

#get an api callable url
url = "https://worldtimeapi.org/api/timezone/"
timezone = "America/New_York"
url = url + timezone

#a resuable function to reliably get time from the internet
def get_time():
    print(f"Accessing url: \n{url}")
    response = requests.get(url)

    #convert response into json
    json = response.json()
    # parse out values we want
    unixtime = json['unixtime']
    raw_offest = json["raw_offset"]

    #create local time in seconds
    location_time = unixtime + raw_offest

    #turn seconds into time components
    current_time = time.localtime(location_time)

    #format and print time and date
    printable_time = f"{current_time.tm_hour:d}:{current_time.tm_min:02d}:{current_time.tm_sec:02d}"
    printable_date = f"{current_time.tm_mon:d}/{current_time.tm_mday:d}/{current_time.tm_year:02d}"
    print(f"printable_time: {printable_time}")
    print(f"printable_date: {printable_date}")

    #set the rtc with the component time in current_time
    clock_datetime = time.struct_time(current_time)

# make your job, here it is just simply playing the alarm
def job():
    play_alarm("calmAlarm.wav")
    print("WAKE UP AND SMELL DA COFFEE")

#call get_time() once, first, to get the time from the web
get_time()

#schedule the jobs, set our alarm for 7 AM every day
schedule.every().day.at("07:00").do(job)
print("scheduled alarm at: 07:00")

schedule.every().day.at("00:00").do(get_time)# update time at midnight each day

# above this comment is the optional code for the alarm

#Set up mpr121
import adafruit_mpr121
from adafruit_debouncer import Button

#set up i2c object
i2c = board.STEMMA_I2C()
touch_pad = adafruit_mpr121.MPR121(i2c)
pads = []
for t_pad in touch_pad:
    pads.append(Button(t_pad, value_when_pressed=True))

#a seperate path than the alarm sound, so the alarm cannot be triggered by the touchpads
path1 = "/sd/sleeps/"
is_playing = False

#our sound files on the SD card
sleep = ["beachsegulls.wav", "birdsforest.wav", "calmocean.wav", "calmRain.wav", "rainforest.wav"]

def play_sound(filename, num):
    with open(path1 + filename, "rb") as wave_file:
        wave = WaveFile(wave_file)
        audio.play(wave, loop=True)
        while audio.playing:
            pads[num].update()
            if pads[num].pressed:
                print(num)
                audio.stop()
            else:
                pass

while True:
   for i in range(len(pads)):
       pads[i].update()
       if pads[i].pressed:
           print(i)
           play_sound(sleep[i], i)


